@@ -84,20 +84,24 @@ C
 cc      !DEC$ ATTRIBUTES DLLEXPORT :: BLOCARF
 C
 CC      IMPLICIT REAL * 8 ( A-H , O-Y )                                   
-      IMPLICIT REAL * 8 ( A-H , O-Z )
+cxx      IMPLICIT REAL * 8 ( A-H , O-Z )
 cc      REAL * 4  TITLE(20) , TTL(13)                                     
 cc      DIMENSION Z(10000)                                                
 cc      DIMENSION  X(200,51) , D(200) , A(50)                             
-      DIMENSION  Z(N), ZS(N)                                            
-      DIMENSION  X(NS0,LAG+1), A(LAG,KMAX)
-      DIMENSION  AIC(KMAX,KMAX), C(KMAX,KMAX)
-      DIMENSION  B(LAG,KMAX), SD(KMAX)
-      DIMENSION  NP(KMAX), NE(KMAX)
+cxx      DIMENSION  Z(N), ZS(N)                                            
+cxx      DIMENSION  X(NS0,LAG+1), A(LAG,KMAX)
+cxx      DIMENSION  AIC(KMAX,KMAX), C(KMAX,KMAX)
+cxx      DIMENSION  B(LAG,KMAX), SD(KMAX)
+cxx      DIMENSION  NP(KMAX), NE(KMAX)
+      INTEGER :: N, LAG, NS0, KMAX, NP(KMAX), NE(KMAX)
+      REAL(8) :: ZS(N), ZMEAN, SUM, AIC(KMAX,KMAX), C(KMAX,KMAX),
+     1           B(LAG,KMAX), A(LAG,KMAX), SD(KMAX), SXX(121,KMAX)
 cc      DATA  TTL / 4H  CU,4HRREN,4HT MO,4HDEL ,4H(AVE,4HRAGE,4H BY ,4HTHE
 cc     1 ,4HBAYE,4HSIAN,4H WEI,4HGHTS,4H)    /                            
 C
-      DIMENSION    SXX(121,KMAX)
-      DIMENSION    F(LAG,KMAX)
+cxx      DIMENSION    SXX(121,KMAX)
+cxx      DIMENSION    F(LAG,KMAX)
+      REAL(8) :: Z(N), X(NS0,LAG+1), F(LAG,KMAX), BB
 C
       EXTERNAL  SETX1
 C
@@ -192,23 +196,23 @@ ccC /* __linux__ */
 cc      WRITE(6,610) IVAR,IFLNAM
 cc      GO TO 999
 C
-  600 FORMAT(/,' !!! Output_Data_File OPEN ERROR ',I8,//5X,100A)
-  610 FORMAT(/,' !!! Input_Data_File OPEN ERROR ',I8,//5X,100A)
+cxx  600 FORMAT(/,' !!! Output_Data_File OPEN ERROR ',I8,//5X,100A)
+cxx  610 FORMAT(/,' !!! Input_Data_File OPEN ERROR ',I8,//5X,100A)
 C
       RETURN
-    1 FORMAT( 16I5 )                                                    
-    2 FORMAT( ///1H ,'  FITTING UP TO THE ORDER  K =',I3,'  IS TRIED',/,
-     1'   BASIC LOCAL SPAN  NS =',I4,/,'   ORIGINAL DATA INPUT DEVICE  M
-     2T =',I3 )                                                         
-    3 FORMAT( //' PROGRAM TIMSAC 78.3.2',/,'   BAYESIAN METHOD OF LOCALL
-     *Y STATIONARY AR MODEL FITTING;   SCALAR CASE',//,'   < BASIC AUTOR
-     *EGRESSIVE MODEL >' )                                              
-    4 FORMAT( 1H ,10X,'Z(I) = A(1)*Z(I-1) + A(2)*Z(I-2) + ... + A(M)*Z(I
-     1-M) + E(I)' )                                                     
-    5 FORMAT( 1H ,10X,'Z(I) = A(1) + A(2)*Z(I-1) + ... + A(M+1)*Z(I-M) +
-     1 E(I)' )                                                          
-    6 FORMAT( 1H ,2X,'WHERE',/,11X,'M:     ORDER OF THE MODEL',/,11X,'E(
-     1I):  GAUSSIAN WHITE NOISE WITH MEAN 0  AND  VARIANCE SD(M).' )    
+cxx    1 FORMAT( 16I5 )                                                    
+cxx    2 FORMAT( ///1H ,'  FITTING UP TO THE ORDER  K =',I3,'  IS TRIED',/,
+cxx     1'   BASIC LOCAL SPAN  NS =',I4,/,'   ORIGINAL DATA INPUT DEVICE  M
+cxx     2T =',I3 )                                                         
+cxx    3 FORMAT( //' PROGRAM TIMSAC 78.3.2',/,'   BAYESIAN METHOD OF LOCALL
+cxx     *Y STATIONARY AR MODEL FITTING;   SCALAR CASE',//,'   < BASIC AUTOR
+cxx     *EGRESSIVE MODEL >' )                                              
+cxx    4 FORMAT( 1H ,10X,'Z(I) = A(1)*Z(I-1) + A(2)*Z(I-2) + ... + A(M)*Z(I
+cxx     1-M) + E(I)' )                                                     
+cxx    5 FORMAT( 1H ,10X,'Z(I) = A(1) + A(2)*Z(I-1) + ... + A(M+1)*Z(I-M) +
+cxx     1 E(I)' )                                                          
+cxx    6 FORMAT( 1H ,2X,'WHERE',/,11X,'M:     ORDER OF THE MODEL',/,11X,'E(
+cxx     1I):  GAUSSIAN WHITE NOISE WITH MEAN 0  AND  VARIANCE SD(M).' )    
       END                                                               
 cc      SUBROUTINE  NONSTB( SETX,Z,X,D,LAG,N0,NS,KMAX,KSW,ISW,TITLE,MJ1,A,
 cc     1SD )                                                              
@@ -258,16 +262,22 @@ C     OUTPUTS:
 C        A:     AR-COEFFICIENTS OF THE CURRENT MODEL                    
 C        SD:    INNOVATION VARIANCE OF THE CURRENT MODEL                
 C                                                                       
-      IMPLICIT  REAL*8  ( A-H,O-Z )                                     
+cxx      IMPLICIT  REAL*8  ( A-H,O-Z )                                     
 CC      REAL*4  Z , TITLE                                                 
 cc      REAL*4  TITLE
 cc      DIMENSION  X(MJ1,1) , D(1) , A(1) , Z(1) , TITLE(1)               
 cc      DIMENSION  F(50,20) , AIC(21) , C(50) , B(50)                     
 cx      DIMENSION  X(MJ1,1) , D(LAG+KSW+1), A(1) , Z(1)
-      DIMENSION  X(MJ1,1) , D(LAG+KSW+1), A(LAG+KSW) , Z(N)
-      DIMENSION  F(LAG+KSW,KMAX1) , AIC(KMAX1) , C(KMAX1) , B(LAG+KSW)
-      DIMENSION  SDD(LAG+KSW+1), AICC(LAG+KSW+1), DIC(LAG+KSW+1)
-      DIMENSION  B1(LAG+KSW), W(LAG+KSW+1)
+cxx      DIMENSION  X(MJ1,1) , D(LAG+KSW+1), A(LAG+KSW) , Z(N)
+cxx      DIMENSION  F(LAG+KSW,KMAX1) , AIC(KMAX1) , C(KMAX1) , B(LAG+KSW)
+cxx      DIMENSION  SDD(LAG+KSW+1), AICC(LAG+KSW+1), DIC(LAG+KSW+1)
+cxx      DIMENSION  B1(LAG+KSW), W(LAG+KSW+1)
+      INTEGER :: N, LAG, N0, NS, KMAX1, KSW, ISW, MJ1, KC
+      REAL(8) :: Z(N), X(MJ1,1), F(LAG+KSW,KMAX1), AIC(KMAX1),
+     1           C(KMAX1), B(LAG+KSW), A(LAG+KSW), SD
+      REAL(8) :: D(LAG+KSW+1), SDD(LAG+KSW+1), AICC(LAG+KSW+1),
+     1           DIC(LAG+KSW+1), B1(LAG+KSW), W(LAG+KSW+1),
+     2           AICB, AICM, SDMIN, PN
 cc      DATA  KC / 0 /                                                    
       EXTERNAL  SETX
 C                                                                       
@@ -281,7 +291,8 @@ C
 C                                                                       
 C     ---  BAYESIAN MODEL FITTED TO THE NEW SPAN  ---                   
 cc      CALL  ARBAYS( X,D,K,LAG,NS,ISW,TITLE,MJ1,A,B,SD,AICB )            
-      CALL ARBAYS( X,D,K,LAG,NS,ISW,MJ1,SDD,AICC,DIC,AICM,SDMIN,IMIN,
+cxx      CALL ARBAYS( X,D,K,LAG,NS,ISW,MJ1,SDD,AICC,DIC,AICM,SDMIN,IMIN,
+      CALL ARBAYS( X,D,K,NS,ISW,MJ1,SDD,AICC,DIC,AICM,SDMIN,IMIN,
      *             A,B1,B,W,SD,PN,AICB )
 C                                                                       
       IF( KC .EQ. 0 )  GO TO 110                                        
@@ -291,11 +302,15 @@ C     ---  PREDICTION ERROR VARIANCE AND AIC OF THE FORMER MODELS  ---
       AIC(1) = AICB                                                     
       DO 30  J=1,KC                                                     
          DO 20  I=1,K                                                   
-   20    D(I) = F(I,J)                                                  
+cxx   20    D(I) = F(I,J)                                                  
+         D(I) = F(I,J)
+   20    CONTINUE
         CALL  ARCOEF( D,K,A )                                           
 cc        CALL  SDCOMP( X,A,D,NS,K,MJ1,SD )                               
         CALL  SDCOMP( X,A,NS,K,MJ1,SD )                               
-   30 AIC(J+1) = NS*DLOG( SD ) + 2.D0                                   
+cxx   30 AIC(J+1) = NS*DLOG( SD ) + 2.D0                                   
+      AIC(J+1) = NS*DLOG( SD ) + 2.D0
+   30 CONTINUE
 C                                                                       
 C                                                                       
 C     ---  BAYESIAN WEIGHTS OF THE MODEL  ---                           
@@ -303,7 +318,9 @@ c-------------------------------   06/11/01
 ccx      AICM = DMIN( AIC,KC )                                             
       AICM = AIC(1)
       DO 33  I=1,KC
-   33 IF( AIC(I) .LT. AICM )  AICM = AIC(I)
+cxx   33 IF( AIC(I) .LT. AICM )  AICM = AIC(I)
+      IF( AIC(I) .LT. AICM )  AICM = AIC(I)
+   33 CONTINUE
 c-------------------------------
       CALL  BAYSWT( AIC,AICM,KC,2,C )                                   
 C                                                                       
@@ -316,12 +333,18 @@ C
 C                                                                       
 C     ---  AVERAGING OF THE MODELS  ---                                 
       DO 40  I=1,K                                                      
-   40 B(I) = B(I)*C(1)                                                  
+cxx   40 B(I) = B(I)*C(1)                                                  
+      B(I) = B(I)*C(1) 
+   40 CONTINUE
       DO 70  J=1,KC                                                     
          DO 50  I=1,K                                                   
-   50    A(I) = F(I,J)                                                  
+cxx   50    A(I) = F(I,J)                                                  
+         A(I) = F(I,J)
+   50    CONTINUE
          DO 60  I=1,K                                                   
-   60    B(I) = B(I) + C(J+1)*A(I)                                      
+cxx   60    B(I) = B(I) + C(J+1)*A(I) 
+         B(I) = B(I) + C(J+1)*A(I)
+   60    CONTINUE                                     
    70 CONTINUE                                                          
 cc      WRITE( 6,5 )     (B(I),I=1,K)                                     
 C                                                                       
@@ -331,13 +354,19 @@ C     ---  AR-COEFFICIENTS OF THE CURRENT BAYESIAN MODEL  ---
 C                                                                       
 C                                                                       
 C     ---  "PARCOR'S" STORED  ---                                       
-      DO 100  J=1,KC                                                    
+cxx      DO 100  J=1,KC                                                    
+      DO 101  J=1,KC
          II = KC1-J                                                     
          DO 100  I=1,K                                                  
-  100 F(I,II+1) = F(I,II)                                               
+cxx  100 F(I,II+1) = F(I,II)
+         F(I,II+1) = F(I,II)
+  100    CONTINUE
+  101 CONTINUE                                               
   110 CONTINUE                                                          
       DO 120  I=1,K                                                     
-  120 F(I,1) = B(I)                                                     
+cxx  120 F(I,1) = B(I)                                                     
+      F(I,1) = B(I)
+  120 CONTINUE
       KC = MIN0( KC+1,KMAX )                                            
 C                                                                       
 C                                                                       
@@ -347,11 +376,11 @@ cc      CALL  SDCOMP( X,A,D,NS,K,MJ1,SD )
 C                                                                       
       RETURN                                                            
 C                                                                       
-    3 FORMAT( ///1H ,13X,'AR-MODEL FITTED TO  !  BAYESIAN WEIGHTS  ! AIC
-     1 WITH RESPECT TO THE PRESENT DATA',/,10X,83(1H-),/,1H ,11X,'CURREN
-     2T BLOCK',9X,'!',F13.5,7X,'!',F21.3 )                              
-    4 FORMAT( 1H ,6X,I5,' PERIOD FORMER BLOCK  !',F13.5,7X,'!',F21.3 )  
-    5 FORMAT( //1H ,'PARTIAL AUTOCORRELATION  B(I) (I=1,K)',/,(1X,10D13.
-     15) )                                                              
+cxx    3 FORMAT( ///1H ,13X,'AR-MODEL FITTED TO  !  BAYESIAN WEIGHTS  ! AIC
+cxx     1 WITH RESPECT TO THE PRESENT DATA',/,10X,83(1H-),/,1H ,11X,'CURREN
+cxx     2T BLOCK',9X,'!',F13.5,7X,'!',F21.3 )                              
+cxx    4 FORMAT( 1H ,6X,I5,' PERIOD FORMER BLOCK  !',F13.5,7X,'!',F21.3 )  
+cxx    5 FORMAT( //1H ,'PARTIAL AUTOCORRELATION  B(I) (I=1,K)',/,(1X,10D13.
+cxx     15) )                                                              
 C                                                                       
       END                                                               
