@@ -6,23 +6,23 @@ C
 C     PROGRAM 5.1.3   AUTO AND/OR CROSS CORRELATIONS VIA FFT.
 C-----------------------------------------------------------------------
 C     ** THIS PROGRAM IS AN ADAPTED VERSION OF THE ALGOL PROCEDURE
-C	  //CROSS CORRELATE// PREPARED BY DR GORDON SANDE AT PRINCETON
-C	  UNIVERSITY IN 1966-7.
+C         //CROSS CORRELATE// PREPARED BY DR GORDON SANDE AT PRINCETON
+C         UNIVERSITY IN 1966-7.
 C     ** DESIGNED BY H. AKAIKE, THE INSTITUTE OF STATISTICAL MATHEMATICS
 C     ** PROGRAMMED BY E. ARAHATA, THE INSTITUTE OF STATISTICAL MATHEMAT
-C	  TOKYO
+C         TOKYO
 C     ** DATE OF THE LATEST REVISION: FEB. 16, 1978
 C     ** THIS PROGRAM WAS ORIGINALLY PUBLISHED IN
-C	 "DAINAMIKKU SISTEMU NO TOKEI-TEKI KAISEKI TO SEIGYO (STATISTICA
-C	 ANALYSIS AND CONTROL OF DYNAMIC SYSTEMS)" BY H. AKAIKE AND
-C	 T. NAKAGAWA, SAIENSU-SHA, TOKYO, 1972 (IN JAPANESE)
+C         "DAINAMIKKU SISTEMU NO TOKEI-TEKI KAISEKI TO SEIGYO (STATISTICA
+C         ANALYSIS AND CONTROL OF DYNAMIC SYSTEMS)" BY H. AKAIKE AND
+C         T. NAKAGAWA, SAIENSU-SHA, TOKYO, 1972 (IN JAPANESE)
 C-----------------------------------------------------------------------
 C     THIS PROGRAM COMPUTES AUTO AND/OR CROSS
 C     COVARIANCES AND CORRELATIONS VIA FFT.
 C     IT REQUIRES FOLLOWING INPUTS:
 C     ISW: ISW=1...AUTO CORRELATION OF X (ONE-CHANNEL)
-C	   ISW=2...AUTO CORRELATIONS OF X AND Y (TWO-CHANNEL)
-C	   ISW=4...AUTO,CROSS CORRELATIONS OF X AND Y (TWO-CHANNEL)
+C           ISW=2...AUTO CORRELATIONS OF X AND Y (TWO-CHANNEL)
+C           ISW=4...AUTO,CROSS CORRELATIONS OF X AND Y (TWO-CHANNEL)
 C     LD: LENGTH OF DATA
 C     LAGH: MAXIMUM LAG
 C     DFORM: INPUT FORMAT SPECIFICATION STATEMENT IN ONE CARD,
@@ -34,17 +34,24 @@ C
 cc      !DEC$ ATTRIBUTES DLLEXPORT :: FFTCORF
 c      USE DFLIB
 C
-	IMPLICIT REAL*8(A-H,O-Y)
-      IMPLICIT COMPLEX*16(Z)
+cxx      IMPLICIT REAL*8(A-H,O-Y)
+cxx      IMPLICIT COMPLEX*16(Z)
 c      REAL*4 DFORM
 c      DIMENSION X(2048),Y(2048),Z(2048),ZS(1025)
 c      DIMENSION CN1(501),CN2(501)
 c      DIMENSION DFORM(20)
 c      REAL*4 XS,YS
 c      DIMENSION XS(2048),YS(2048)
-      DIMENSION X1(LD),Y1(LD),XA(N,2),X(N),Y(N)
-	DIMENSION Z(N),ZS(N/2+1)
-      DIMENSION CNA1(LAGH1,2),CN1(LAGH1),CN2(LAGH1),AMEAN(2)
+cxx      DIMENSION X1(LD),Y1(LD),XA(N,2),X(N),Y(N)
+cxx      DIMENSION Z(N),ZS(N/2+1)
+cxx      DIMENSION CNA1(LAGH1,2),CN1(LAGH1),CN2(LAGH1),AMEAN(2)
+      INTEGER :: LD, LAGH1, N, N2P, ISW
+      REAL(8) :: X1(LD), Y1(LD), XA(N,2), X(N), Y(N), CNA1(LAGH1,2),
+     1           CN1(LAGH1), CN2(LAGH1), AMEAN(2)
+      REAL(8) :: CST0, CST1, CST2, AN, ALD, ALD1, RF, SF,
+     1           RG, SG, XI, XNI, YI, YNI, X0, XMEAN, YMEAN,
+     2           CX0, Y0
+      COMPLEX(kind(0d0)) :: Z(N), ZS(N/2+1), ZI, ZNI
 C     INPUT / OUTPUT DATA FILE OPEN
 c	CHARACTER(100) DFNAM
 c	DFNAM='fftcor.out'
@@ -106,12 +113,15 @@ c      GO TO 202
 c  201 WRITE(6,55)
 c      CALL PRCOL2(X,Y,1,LD,0)
 C     MEAN DELETION
-  202 CALL DMEADL(X,LD,XMEAN)
+cxx  202 CALL DMEADL(X,LD,XMEAN)
+      CALL DMEADL(X,LD,XMEAN)
       IF(ISW.EQ.1) GO TO 203
       CALL DMEADL(Y,LD,YMEAN)
 C     DOUBLE PRECISION COMPLEX REPRESENTATION
   203 DO 31 I=1,N
-   31 Z(I)=DCMPLX(X(I),Y(I))
+cxx   31 Z(I)=DCMPLX(X(I),Y(I))
+      Z(I)=DCMPLX(X(I),Y(I))
+   31 CONTINUE
 C     FOURIER TRANSFORM OF Z
       ISG=-1
       CALL MIXRAD(Z,N,N2P,ISG)
@@ -120,7 +130,9 @@ C     RAW SPECTRUM COMPUTATION
       DO 32 I=2,M
       X(I)=DREAL(Z(I))**2+DIMAG(Z(I))**2
       NI=NP2-I
-   32 X(NI)=X(I)
+cxx   32 X(NI)=X(I)
+      X(NI)=X(I)
+   32 CONTINUE
       X(1)=DREAL(Z(1))**2
       X(M1)=DREAL(Z(M1))**2
       GO TO 205
@@ -152,18 +164,25 @@ C     DECOMPOSITION AND RAW SPECTRUM COMPUTATION
 C     RAW CROSS SPECTRUM COMPUTATION
       DO 126 I=2,M
       NI=NP2-I
-  126 ZS(I)=CST2*Z(I)*Z(NI)
+cxx  126 ZS(I)=CST2*Z(I)*Z(NI)
+      ZS(I)=CST2*Z(I)*Z(NI)
+  126 CONTINUE
       ZS(1)=DREAL(Z(1))*DIMAG(Z(1))
       ZS(M1)=DREAL(Z(M1))*DIMAG(Z(M1))
 C     AUTO COVARIANCE COMPUTATION
   205 DO 33 I=1,N
-   33 Z(I)=DCMPLX(X(I),Y(I))
+cxx   33 Z(I)=DCMPLX(X(I),Y(I))
+      Z(I)=DCMPLX(X(I),Y(I))
+   33 CONTINUE
 C     FOURIER TRANSFORM
-  215 CALL MIXRAD(Z,N,N2P,ISG)
+cxx  215 CALL MIXRAD(Z,N,N2P,ISG)
+      CALL MIXRAD(Z,N,N2P,ISG)
       II=1
       DO 34 I=1,LAGH1
       X(I)=DREAL(Z(I))*ALD1
-   34 XA(I,II)=X(I)
+cxx   34 XA(I,II)=X(I)
+      XA(I,II)=X(I)
+   34 CONTINUE
       X0=X(1)
 c      AMEAN=XMEAN
       AMEAN(II)=XMEAN
@@ -183,7 +202,9 @@ c      WRITE(7,2) (X(I),I=1,LAGH1)
       II=2
       DO 35 I=1,LAGH1
       X(I)=DIMAG(Z(I))*ALD1
-   35 XA(I,II)=X(I)
+cxx   35 XA(I,II)=X(I)
+      XA(I,II)=X(I)
+   35 CONTINUE
       Y0=X(1)
 c      AMEAN=YMEAN
       AMEAN(II)=YMEAN
@@ -193,7 +214,9 @@ C     CROSS COVARIANCE COMPUTATION
       DO 127 I=2,M
       NI=NP2-I
       Z(I)=ZS(I)
-  127 Z(NI)=DCONJG(ZS(I))
+cxx  127 Z(NI)=DCONJG(ZS(I))
+      Z(NI)=DCONJG(ZS(I))
+  127 CONTINUE
       Z(1)=ZS(1)
       Z(M1)=ZS(M1)
 C     FOURIER TRANSFORM
@@ -202,7 +225,9 @@ C     FOURIER TRANSFORM
       I1=I+1
       J1=NP1-I
       X(I1)=DREAL(Z(I1))*ALD1
-   41 Y(I1)=DREAL(Z(J1))*ALD1
+cxx   41 Y(I1)=DREAL(Z(J1))*ALD1
+      Y(I1)=DREAL(Z(J1))*ALD1
+   41 CONTINUE
       X(1)=DREAL(Z(1))*ALD1
       Y(1)=X(1)
 C     NORMALIZATION
