@@ -1,4 +1,4 @@
-	SUBROUTINE FPEAUTF(L,N,SD,CXX,SSD,FPE,RFPE,D,CHI2,
+      SUBROUTINE FPEAUTF(L,N,SD,CXX,SSD,FPE,RFPE,D,CHI2,
      & OFPE1,OFPE2,ORFPE,MO,OSD,A,AO)
 C
       INCLUDE 'timsac_f.h'
@@ -7,12 +7,12 @@ C     PROGRAM 5.3.1   FPE AUTO
 C-----------------------------------------------------------------------
 C     ** DESIGNED BY H. AKAIKE, THE INSTITUTE OF STATISTICAL MATHEMATICS
 C     ** PROGRAMMED BY E. ARAHATA, THE INSTITUTE OF STATISTICAL MATHEMAT
-C	  TOKYO
+C         TOKYO
 C     ** DATE OF THE LATEST REVISION: MARCH 25, 1977
 C     ** THIS PROGRAM WAS ORIGINALLY PUBLISHED IN
-C	 "DAINAMIKKU SISTEMU NO TOKEI-TEKI KAISEKI TO SEIGYO (STATISTICA
-C	 ANALYSIS AND CONTROL OF DYNAMIC SYSTEMS)" BY H. AKAIKE AND
-C	 T. NAKAGAWA, SAIENSU-SHA, TOKYO, 1972 (IN JAPANESE)
+C         "DAINAMIKKU SISTEMU NO TOKEI-TEKI KAISEKI TO SEIGYO (STATISTICA
+C         ANALYSIS AND CONTROL OF DYNAMIC SYSTEMS)" BY H. AKAIKE AND
+C         T. NAKAGAWA, SAIENSU-SHA, TOKYO, 1972 (IN JAPANESE)
 C-----------------------------------------------------------------------
 C     THIS PROGRAM PERFORMS FPE(FINAL PREDICTION ERROR) COMPUTATION FOR
 C     ONE-DIMENSIONAL AR-MODEL. A CARD CONTAINING THE FOLLOWING
@@ -29,17 +29,21 @@ C
 cc      !DEC$ ATTRIBUTES DLLEXPORT :: FPEAUTF
 c      USE DFLIB
 C
-      IMPLICIT REAL*8(A-H,O-Z)
+cxx      IMPLICIT REAL*8(A-H,O-Z)
 c      DIMENSION CXX(501),A(501),B(501),AO(501)
-      DIMENSION CXX(L),A(L,L),B(L),AO(L)
-	DIMENSION SSD(L),FPE(L),RFPE(L),D(L),CHI2(L)
+cxx      DIMENSION CXX(L),A(L,L),B(L),AO(L)
+cxx      DIMENSION SSD(L),FPE(L),RFPE(L),D(L),CHI2(L)
+      INTEGER :: L, N, MO
+      REAL(8) :: SD, CXX(L), SSD(L), FPE(L), RFPE(L), D(L), CHI2(L),
+     1           OFPE1, OFPE2, ORFPE, OSD, A(L,L), AO(L)
+      REAL(8) :: B(L), AN, ANP1, ANM1, CST1, OOFPE, SE, SD0, D2
 C
 C     INPUT / OUTPUT DATA FILE OPEN
-c	CHARACTER(100) DFNAM
-c	CALL SETWND
-c	DFNAM='fpeaut.out'
-c	CALL FLOPN3(DFNAM,NFL)
-c	IF (NFL.EQ.0) GO TO 999
+c      CHARACTER(100) DFNAM
+c      CALL SETWND
+c      DFNAM='fpeaut.out'
+c      CALL FLOPN3(DFNAM,NFL)
+c      IF (NFL.EQ.0) GO TO 999
 C     L SPECIFICATION
 c      READ(5,1) L
 C     READING THE OUTPUT OF PROGRAM 5.1.1 AUTCOR
@@ -60,7 +64,7 @@ c      OOFPE=CST1/OFPE
       ORFPE=CST1
       OSD=SD
       MO=0
-	OFPE2=OFPE1
+      OFPE2=OFPE1
 c      WRITE(6,155)
 c      WRITE(6,156)
 c      WRITE(6,57) N,L
@@ -70,7 +74,7 @@ c      CALL PRCOL1(CXX,1,L,0)
 c      WRITE(6,157)
 c      WRITE(6,58) OFPE
       SE=CXX(1)
-	SD0=SD
+      SD0=SD
 C
       DO 400 M=1,L
       MP1=M+1
@@ -82,7 +86,7 @@ c      SD=(CST1-D2)*SD
       A(M,M)=D(M)
       D2=D(M)*D(M)
       SSD(M)=(CST1-D2)*SD0
-	SD0=SSD(M)
+      SD0=SSD(M)
       ANP1=NP1+M
       ANM1=NM1-M
 c      FPE=(ANP1/ANM1)*SD
@@ -96,14 +100,14 @@ C     A(I) COMPUTATION
       LM=M-1
       DO 420 I=1,LM
 c  420 A(I)=A(I)-D*B(I)
-	A(I,M)=A(I,M-1)-D(M)*B(I)
+      A(I,M)=A(I,M-1)-D(M)*B(I)
   420 CONTINUE
 c  410 DO 421 I=1,M
   410 CONTINUE
-	DO 421 I=1,M
+      DO 421 I=1,M
       IM=MP1-I
 c  421 B(I)=A(IM)
-	B(I)=A(IM,M)
+      B(I)=A(IM,M)
   421 CONTINUE
 c      WRITE(6,60) M
 c      WRITE(6,61) SD,FPE,RFPE
@@ -122,11 +126,15 @@ c      OSD=SD
       MO=M
       DO 430 I=1,M
 c  430 AO(I)=A(I)
-  430 AO(I)=A(I,M)
+cxx  430 AO(I)=A(I,M)
+      AO(I)=A(I,M)
+  430 CONTINUE
   440 IF(M.EQ.L) GO TO 400
       SE=CXX(MP1)
       DO 441 I=1,M
-  441 SE=SE-B(I)*CXX(I)
+cxx  441 SE=SE-B(I)*CXX(I)
+      SE=SE-B(I)*CXX(I)
+  441 CONTINUE
   400 CONTINUE
 C
 c      WRITE(6,63) OFPE,MO
@@ -136,7 +144,7 @@ c      WRITE(7,2) OSD
 c      IF(MO.LE.0) GO TO 699
 c      WRITE(7,2) (AO(I),I=1,MO)
 c  699 CONTINUE
-c	CALL FLCLS3(NFL)
+c      CALL FLCLS3(NFL)
 c    1 FORMAT(10I5)
 c    2 FORMAT(4D20.10)
 c   57 FORMAT(1H ,2HN=,I5,5X,2HL=,I5)
@@ -152,5 +160,5 @@ c  141 FORMAT(1H ,4X,1H0,D16.5)
 c  155 FORMAT(1H ,24HPROGRAM 5.3.1   FPE AUTO)
 c  156 FORMAT(1H ,17HINITIAL CONDITION)
 c  157 FORMAT(1H ,2HM=,4X,1H0)
-	RETURN
+      RETURN
       END SUBROUTINE
