@@ -11,12 +11,12 @@ C      SUBROUTINE SFPEC(SD,N,K,IR,MS,Z,RZ,OOZ,AIC)
 C-----------------------------------------------------------------------
 C     ** DESIGNED BY H. AKAIKE, THE INSTITUTE OF STATISTICAL MATHEMATICS
 C     ** PROGRAMMED BY E. ARAHATA, THE INSTITUTE OF STATISTICAL MATHEMAT
-C	  TOKYO
+C         TOKYO
 C     ** DATE OF THE LATEST REVISION: MARCH 25, 1977
 C     ** THIS PROGRAM WAS ORIGINALLY PUBLISHED IN
-C	 "DAINAMIKKU SISTEMU NO TOKEI-TEKI KAISEKI TO SEIGYO (STATISTICA
-C	 ANALYSIS AND CONTROL OF DYNAMIC SYSTEMS)" BY H. AKAIKE AND
-C	 T. NAKAGAWA, SAIENSU-SHA, TOKYO, 1972 (IN JAPANESE)
+C         "DAINAMIKKU SISTEMU NO TOKEI-TEKI KAISEKI TO SEIGYO (STATISTICA
+C         ANALYSIS AND CONTROL OF DYNAMIC SYSTEMS)" BY H. AKAIKE AND
+C         T. NAKAGAWA, SAIENSU-SHA, TOKYO, 1972 (IN JAPANESE)
 C-----------------------------------------------------------------------
 C     THIS PROGRAM PERFORMS FPEC(AR-MODEL FITTING FOR CONTROL)
 C     COMPUTATION.
@@ -35,24 +35,30 @@ C
 cc      !DEC$ ATTRIBUTES DLLEXPORT :: FPEC7F
 c      USE DFLIB
 C
-      IMPLICIT REAL*8(A-H,O-Z)
+cxx      IMPLICIT REAL*8(A-H,O-Z)
 c      DIMENSION R1(30,10,10),A1(30,10,10),B1(30,10,10),AO(30,10,10)
 c      DIMENSION SD(10,10),SE(10,10),SF(10,10),OSD(10,10)
 c      DIMENSION XSD(10,10),XSF(10,10),D(10,10),E(10,10),Z1(10,10)
 c      DIMENSION INW(10),C1(10,10)
-      DIMENSION INW(IP),R1(L+1,IP0,IP0),R2(L+1,IP,IP)
-      DIMENSION FPEC(0:L),RFPEC(0:L),AIC(0:L)
-      DIMENSION OSD(IR,IR),AO(L,IR,IP)
-      DIMENSION A1(L,IP,IP),B1(L,IP,IP),C1(IP0,IP0)
-      DIMENSION SD(IP,IP),SE(IP,IP),SF(IP,IP)
-      DIMENSION XSD(IP,IP),XSF(IP,IP),D(IP,IP),E(IP,IP),Z1(IP,IP)
+cxx      DIMENSION INW(IP),R1(L+1,IP0,IP0),R2(L+1,IP,IP)
+cxx      DIMENSION FPEC(0:L),RFPEC(0:L),AIC(0:L)
+cxx      DIMENSION OSD(IR,IR),AO(L,IR,IP)
+cxx      DIMENSION A1(L,IP,IP),B1(L,IP,IP),C1(IP0,IP0)
+cxx      DIMENSION SD(IP,IP),SE(IP,IP),SF(IP,IP)
+cxx      DIMENSION XSD(IP,IP),XSF(IP,IP),D(IP,IP),E(IP,IP),Z1(IP,IP)
+      INTEGER :: N, L, IR, IP, IP0, INW(IP), IFPEC
+      REAL(8) :: R1(L+1,IP0,IP0), R2(L+1,IP,IP), FPEC(0:L), RFPEC(0:L),
+     1           AIC(0:L), OFPEC, ORFPEC, OAIC, OSD(IR,IR), AO(L,IR,IP)
+      REAL(8) :: A1(L,IP,IP), B1(L,IP,IP), C1(IP0,IP0), SD(IP,IP),
+     1           SE(IP,IP), SF(IP,IP), XSD(IP,IP), XSF(IP,IP),
+     2           D(IP,IP), E(IP,IP), Z1(IP,IP), OOFPEC, SDDET, SFDET
 C
 C     INPUT / OUTPUT DATA FILE OPEN
-c	CHARACTER(100) DFNAM
-c	DFNAM='fpec.out'
-c	CALL SETWND
-c	CALL FLOPN3(DFNAM,NFL)
-c	IF (NFL.EQ.0) GO TO 999
+c      CHARACTER(100) DFNAM
+c      DFNAM='fpec.out'
+c      CALL SETWND
+c      CALL FLOPN3(DFNAM,NFL)
+c      IF (NFL.EQ.0) GO TO 999
 C     INITIAL CONDITION INPUT
 c      READ(5,1) L,IR,IL
 c      IP=IR+IL
@@ -63,15 +69,23 @@ c      READ(5,1) N,LAGH,IP0
 c      LAGH1=LAGH+1
 c      CALL RECOVA(R1,LAGH1,L1,IP0,MJ0,MJ)
       DO 10 II=1,L1
-      DO 20 I=1,IP0
+cxx      DO 20 I=1,IP0
+      DO 22 I=1,IP0
       DO 20 J=1,IP0
-   20 C1(I,J)=R1(II,I,J)
+cxx   20 C1(I,J)=R1(II,I,J)
+      C1(I,J)=R1(II,I,J)
+   20 CONTINUE
+   22 CONTINUE
 C     MATRIX REARRANGEMENT BY INW
-c	  CALL REARRA(C1,INW,IP0,IP,MJ)
+c        CALL REARRA(C1,INW,IP0,IP,MJ)
       CALL REARRA(C1,INW,IP0,IP)
-      DO 21 I=1,IP
+cxx      DO 21 I=1,IP
+      DO 23 I=1,IP
       DO 21 J=1,IP
-   21 R2(II,I,J)=C1(I,J)
+cxx   21 R2(II,I,J)=C1(I,J)
+      R2(II,I,J)=C1(I,J)
+   21 CONTINUE
+   23 CONTINUE
    10 CONTINUE
 C     INITIAL CONDITION AND COVARIANCE PRINT OUT
 c      WRITE(6,39)
@@ -81,7 +95,8 @@ c      WRITE(6,259) (INW(I),I=1,1,IP)
 c      WRITE(6,42)
 c      CALL PRMAT3(R1,L1,IP,IP,1,MJ0,MJ,MJ)
 C     INITIAL SD, SF, SE COMPUTATION
-      DO 330 II=1,IP
+cxx      DO 330 II=1,IP
+      DO 331 II=1,IP
       DO 330 JJ=1,IP
 c      SD(II,JJ)=R1(1,II,JJ)
       SD(II,JJ)=R2(1,II,JJ)
@@ -89,20 +104,23 @@ c      SD(II,JJ)=R1(1,II,JJ)
 c      SE(II,JJ)=R1(2,II,JJ)
       SE(II,JJ)=R2(2,II,JJ)
       XSD(II,JJ)=SD(II,JJ)
-  330 XSF(II,JJ)=SF(II,JJ)
+cxx  330 XSF(II,JJ)=SF(II,JJ)
+      XSF(II,JJ)=SF(II,JJ)
+  330 CONTINUE
+  331 CONTINUE
 C     0-TH STEP COMPUTATION
       IFPEC=0
       MS=0
 C     OFPEC, ORFPEC COMPUTATION
 c      CALL SFPEC(SD,N,IP,IR,MS,OFPEC,ORFPEC,OOFPEC,MJ)
-	CALL SFPEC(SD,N,IP,IR,MS,FPEC(0),RFPEC(0),OOFPEC,AIC(0))
+      CALL SFPEC(SD,N,IP,IR,MS,FPEC(0),RFPEC(0),OOFPEC,AIC(0))
 C     OFPEC, ORFPEC PRINT OUT
 c      WRITE(6,600)
 c      WRITE(6,264) MS,OFPEC,ORFPEC,AIC
 c      OAIC=AIC
       OAIC=AIC(0)
-	OFPEC=FPEC(0)
-	ORFPEC=RFPEC(0)
+      OFPEC=FPEC(0)
+      ORFPEC=RFPEC(0)
 C     ITERATION M=1 TO L
       DO 400 M=1,L
 C     INVERSE OF SD, SF COMPUTATION
@@ -124,10 +142,14 @@ c      CALL SUBTAL(SF,Z1,IP,IP,MJ,MJ)
       CALL MULPLY(E,SE,Z1,IP,IP,IP)
       CALL SUBTAL(SF,Z1,IP,IP)
       MS=M
-	DO 410 II=1,IP
+cxx      DO 410 II=1,IP
+      DO 411 II=1,IP
       DO 410 JJ=1,IP
       XSD(II,JJ)=SD(II,JJ)
-  410 XSF(II,JJ)=SF(II,JJ)
+cxx  410 XSF(II,JJ)=SF(II,JJ)
+      XSF(II,JJ)=SF(II,JJ)
+  410 CONTINUE
+  411 CONTINUE
 C     FPEC,RFPEC COMPUTATION
 c      CALL SFPEC(SD,N,IP,IR,MS,FPEC,RFPEC,OOFPEC,MJ)
       CALL SFPEC(SD,N,IP,IR,MS,FPEC(M),RFPEC(M),OOFPEC,AIC(M))
@@ -146,13 +168,21 @@ c      ORFPEC=RFPEC
       OFPEC=FPEC(M)
       ORFPEC=RFPEC(M)
       IFPEC=M
-      DO 560 II=1,IR
+cxx      DO 560 II=1,IR
+      DO 566 II=1,IR
       DO 560 JJ=1,IR
-  560 OSD(II,JJ)=SD(II,JJ)
+cxx  560 OSD(II,JJ)=SD(II,JJ)
+      OSD(II,JJ)=SD(II,JJ)
+  560 CONTINUE
+  566 CONTINUE
       DO 561 I=1,M
       DO 562 II=1,IR
-      DO 562 JJ=1,IP
-  562 AO(I,II,JJ)=A1(I,II,JJ)
+cxx      DO 562 JJ=1,IP
+      DO 563 JJ=1,IP
+cxx  562 AO(I,II,JJ)=A1(I,II,JJ)
+      AO(I,II,JJ)=A1(I,II,JJ)
+  563 CONTINUE
+  562 CONTINUE
   561 CONTINUE
   440 IF(M.EQ.L) GO TO 400
 C     SE COMPUTATION
@@ -177,7 +207,7 @@ c      DO 582 II=1,IR
 c  582 WRITE(7,2) (AO(I,II,JJ),JJ=1,IP)
 c  581 CONTINUE
 c  699 CONTINUE
-c	CALL FLCLS3(NFL)
+c      CALL FLCLS3(NFL)
 c  999 CONTINUE
 c    1 FORMAT(10I5)
 c    2 FORMAT(4D20.10)
@@ -192,16 +222,19 @@ c  607 FORMAT(1H ,13HMINIMUM FPEC=,D12.5,2X,14HMINIMUM RFPEC=,D12.5,2X,14
 c     AHATTAINED AT M=,I5)
 c  608 FORMAT(//1H ,10X,10HOSD(II,JJ))
 c  609 FORMAT(//1H ,10X,10H(A(I)B(I)))
-	RETURN
+      RETURN
       END SUBROUTINE
 C
 c      SUBROUTINE SFPEC(SD,N,K,IR,MS,Z,RZ,OOZ,MJ,AIC)
       SUBROUTINE SFPEC(SD,N,K,IR,MS,Z,RZ,OOZ,AIC)
 C     FPEC COMPUTATION
-      IMPLICIT REAL*8(A-H,O-Z)
+cxx      IMPLICIT REAL*8(A-H,O-Z)
 c      COMMON /COMA/AIC
-      DIMENSION SD(K,K)
-      DIMENSION SD1(IR,IR)
+cxx      DIMENSION SD(K,K)
+cxx      DIMENSION SD1(IR,IR)
+      INTEGER :: N, K, IR, MS
+      REAL(8) :: SD(K,K), Z, RZ, OOZ, AIC
+      REAL(8) :: SD1(IR,IR), AN, ANP, ANM, AP, APR, CST1, SDRM, ARM2
       AN=N
       KM=K*MS
       ANP=N+1+KM
@@ -210,8 +243,12 @@ c      COMMON /COMA/AIC
       APR=AP**IR
       CST1=1.0D-00
       DO 9 I=1,IR
-      DO 9 J=1,IR
-    9 SD1(I,J)=SD(I,J)
+cxx      DO 9 J=1,IR
+      DO 8 J=1,IR
+cxx    9 SD1(I,J)=SD(I,J)
+      SD1(I,J)=SD(I,J)
+    8 CONTINUE
+    9 CONTINUE
 c      CALL SUBDET(SD1,SDRM,IR,MJ)
       CALL SUBDET(SD1,SDRM,IR,IR)
       Z=APR*SDRM
