@@ -12,12 +12,12 @@ C      SUBROUTINE SIMCOH(P1,P2,C,S,P3,LAGH1)
 C-----------------------------------------------------------------------
 C     ** DESIGNED BY H. AKAIKE, THE INSTITUTE OF STATISTICAL MATHEMATICS
 C     ** PROGRAMMED BY E. ARAHATA, THE INSTITUTE OF STATISTICAL MATHEMAT
-C	  TOKYO
+C         TOKYO
 C     ** DATE OF THE LATEST REVISION: MARCH 25, 1977
 C     ** THIS PROGRAM WAS ORIGINALLY PUBLISHED IN
-C	 "DAINAMIKKU SISTEMU NO TOKEI-TEKI KAISEKI TO SEIGYO (STATISTICA
-C	 ANALYSIS AND CONTROL OF DYNAMIC SYSTEMS)" BY H. AKAIKE AND
-C	 T. NAKAGAWA, SAIENSU-SHA, TOKYO, 1972 (IN JAPANESE)
+C         "DAINAMIKKU SISTEMU NO TOKEI-TEKI KAISEKI TO SEIGYO (STATISTICA
+C         ANALYSIS AND CONTROL OF DYNAMIC SYSTEMS)" BY H. AKAIKE AND
+C         T. NAKAGAWA, SAIENSU-SHA, TOKYO, 1972 (IN JAPANESE)
 C-----------------------------------------------------------------------
 C     THIS PROGRAM COMPUTES MULTIPLE SPECTRUM ESTIMATES FROM THE OUTPUT
 C     OF PROGRAM 5.1.2 MULCOR, USING WINDOWS W1 AND W2.
@@ -31,25 +31,30 @@ C
 cc      !DEC$ ATTRIBUTES DLLEXPORT :: MULSPEF
 c      USE DFLIB
 C
-	IMPLICIT REAL*8(A-H,O-Z)
+cxx      IMPLICIT REAL*8(A-H,O-Z)
 c      DIMENSION C(501),S(501),G(501)                                    
 c      DIMENSION FC(501),FS(501),P1(501),P2(501),P3(501)                 
 c      DIMENSION A1(10),A2(10)                                           
 c      DIMENSION P(10020)                                                
 c      DIMENSION X(101,10,10)                                            
-      DIMENSION C(LAGH1),S(LAGH1),G(LAGH1),CV(LAGH3,K,K)
-      DIMENSION FC(LAGH1),FS(LAGH1)
-      DIMENSION P1(LAGH1,K,K),P2(LAGH1,K,K),PS(LAGH1,K)
-      DIMENSION PCH1(LAGH1,K,K),PCH2(LAGH1,K,K)
-      DIMENSION A1(2),A2(3)
-      DIMENSION P(LAGH1*2*K)
+cxx      DIMENSION C(LAGH1),S(LAGH1),G(LAGH1),CV(LAGH3,K,K)
+cxx      DIMENSION FC(LAGH1),FS(LAGH1)
+cxx      DIMENSION P1(LAGH1,K,K),P2(LAGH1,K,K),PS(LAGH1,K)
+cxx      DIMENSION PCH1(LAGH1,K,K),PCH2(LAGH1,K,K)
+cxx      DIMENSION A1(2),A2(3)
+cxx      DIMENSION P(LAGH1*2*K)
+      INTEGER :: N, K, LAGH1, LAGH3
+      REAL(8) :: CV(LAGH3,K,K), P1(LAGH1,K,K), P2(LAGH1,K,K),
+     1           PS(LAGH1,K), PCH1(LAGH1,K,K), PCH2(LAGH1,K,K)
+      REAL(8) :: C(LAGH1), S(LAGH1), G(LAGH1), FC(LAGH1), FS(LAGH1),
+     1           A1(2), A2(3), P(LAGH1*2*K), CT5
 C
 C     INPUT / OUTPUT DATA FILE OPEN
-c	CHARACTER(100) DFNAM
-c	DFNAM='mulspe.out'
-c	CALL SETWND
-c	CALL FLOPN3(DFNAM,NFL)
-c	IF (NFL.EQ.0) GO TO 999
+c      CHARACTER(100) DFNAM
+c      DFNAM='mulspe.out'
+c      CALL SETWND
+c      CALL FLOPN3(DFNAM,NFL)
+c      IF (NFL.EQ.0) GO TO 999
 C     WINDOW W1 DEFINITION
       MLA1=2
       A1(1)=0.5D-00
@@ -75,8 +80,8 @@ c      WRITE(6,64)
 c      CALL PRCOL1(A2,1,MLA2,1)
 c      WRITE(7,1) N,LAGH,K
 C     COMPUTATION STARTS HERE WITH DISK AS EXTERNAL MEMORY.
-CC	REWIND 1
-c	IP=0
+CC      REWIND 1
+c      IP=0
       CT5=0.5D-00
       LAG2=LAGH1+LAGH1
       DO 10 II=1,K
@@ -84,9 +89,13 @@ C     AUTO COVARIANCE INPUT
 c      READ(5,1) IR0,IC0
 c      READ(5,2) (C(I),I=1,LAGH3)
       DO 15 I=1,LAGH1
-   15 C(I)=CV(I,II,II)
+cxx   15 C(I)=CV(I,II,II)
+      C(I)=CV(I,II,II)
+   15 CONTINUE
       DO 20 I=1,LAGH1
-   20 G(I)=C(I)+C(I)
+cxx   20 G(I)=C(I)+C(I)
+      G(I)=C(I)+C(I)
+   20 CONTINUE
       G(1)=CT5*G(1)
       G(LAGH1)=CT5*G(LAGH1)
 C     F-COS TRANSFORMATION
@@ -115,7 +124,9 @@ cc	LAG2=LAGH1+LAGH1
 c      P(I1)=P1(I)
 c   21 P(I2)=P2(I)
       P(I1)=P1(I,II,II)
-   21 P(I2)=P2(I,II,II)
+cxx   21 P(I2)=P2(I,II,II)
+      P(I2)=P2(I,II,II)
+   21 CONTINUE
       IF(II.EQ.1) GO TO 10
 C     CROSS COVARIANCE INPUT
       IM1=II-1
@@ -126,16 +137,22 @@ c      READ(5,1) IR2,IC2
 c      READ(5,2) (S(I),I=1,LAGH3)
       DO 25 I=1,LAGH1
       C(I)=CV(I,II,JJ)
-   25 S(I)=CV(I,JJ,II)
+cxx   25 S(I)=CV(I,JJ,II)
+      S(I)=CV(I,JJ,II)
+   25 CONTINUE
 C     F-COS TRANSFORMATION
       DO 30 I=1,LAGH1
-   30 G(I)=C(I)+S(I)
+cxx   30 G(I)=C(I)+S(I)
+      G(I)=C(I)+S(I)
+   30 CONTINUE
       G(1)=CT5*G(1)
       G(LAGH1)=CT5*G(LAGH1)
       CALL FGERCO(G,LAGH1,FC,LAGH1)
 C     F-SIN TRANSFORMATION
       DO 31 I=1,LAGH1
-   31 G(I)=S(I)-C(I)
+cxx   31 G(I)=S(I)-C(I)
+      G(I)=S(I)-C(I)
+   31 CONTINUE
       G(1)=CT5*G(1)
       G(LAGH1)=CT5*G(LAGH1)
       CALL FGERSI(G,LAGH1,FS,LAGH1)
@@ -151,7 +168,9 @@ C     SIMPLE COHERENCE COMPUTATION
       I1=II1+I
       I2=JJ1+I
       C(I)=P(I1)
-   32 S(I)=P(I2)
+cxx   32 S(I)=P(I2)
+      S(I)=P(I2)
+   32 CONTINUE
 c      CALL SIMCOH(P1,P2,C,S,P3,LAGH1)
       IF (ISW.EQ.1) THEN
          CALL SIMCOH(P1(1,II,JJ),P1(1,JJ,II),C,S,PCH1(1,II,JJ),LAGH1)
@@ -169,7 +188,7 @@ c  268 WRITE(6,167)
 c      CALL PRCOL3(P1,P2,P3,1,LAGH1,1)
       IF(ISW.LT.0) GO TO 11
 C     CROSS SPECTRUM STORE (DISK)
-CC	WRITE(1) (P1(I),I=1,LAGH1),(P2(I),I=1,LAGH1)
+CC     WRITE(1) (P1(I),I=1,LAGH1),(P2(I),I=1,LAGH1)
 C     SMOOTHING BY WINDOW W2
       ISW=-1
       IWD=LAGH1
@@ -178,7 +197,7 @@ c      CALL CROSSP(FC,FS,P1,P2,LAGH1,A2,MLA2)
       GO TO 33
    11 CONTINUE
    10 CONTINUE
-CC	END FILE 1
+CC      END FILE 1
 C     SPECTRUM (SMOOTHED BY WINDOW W1) PUNCH OUT
 c      LC=LAGH1
 c      IL=101
@@ -191,8 +210,8 @@ c      J2=J1+ILM1
 c      IF(J2.LE.LC) GO TO 413
 c  412 J2=LC
 c  413 CONTINUE
-CC	REWIND 1
-c	IP=0
+CC      REWIND 1
+c      IP=0
 c      DO 500 II=1,K
 c      II1=(II-1)*LAG2
 c      DO 520 I=J1,J2
@@ -202,7 +221,7 @@ c  520 X(I0,II,II)=P(I1)
 c      IF(II.EQ.1) GO TO 500
 c      IM1=II-1
 c      DO 501 JJ=1,IM1
-CC	READ(1) (P1(I),I=1,LAGH1),(P2(I),I=1,LAGH1)
+CC      READ(1) (P1(I),I=1,LAGH1),(P2(I),I=1,LAGH1)
 c      DO 530 I=J1,J2
 c      I0=I-IB
 c      X(I0,II,JJ)=P1(I)
@@ -242,10 +261,13 @@ C     P1,P2: REAL AND IMAGINARY PART OF SMOOTHED CROSS SPECTRUM
 C     LAGH1: DIMENSION OF FC, FS AND PI (I=1,2)
 C     A: SMOOTHING COEFFICIENTS
 C     LA1: DIMENSION OF A (LESS THAN 11)
-      IMPLICIT REAL*8(A-H,O-Z)
-      DIMENSION FC(LAGH1),FS(LAGH1),P1(LAGH1),P2(LAGH1)
-      DIMENSION A(LA1)
-      DIMENSION FC1(521),FS1(521)
+cxx      IMPLICIT REAL*8(A-H,O-Z)
+cxx      DIMENSION FC(LAGH1),FS(LAGH1),P1(LAGH1),P2(LAGH1)
+cxx      DIMENSION A(LA1)
+cxx      DIMENSION FC1(521),FS1(521)
+      INTEGER :: LAGH1, LA1
+      REAL(8) :: FC(LAGH1), FS(LAGH1), P1(LAGH1), P2(LAGH1), A(LA1)
+      REAL(8) :: FC1(521), FS1(521)
       LA=LA1-1
       LAGSHF=LAGH1+2*LA
 C     FC SHIFT-RIGHT BY LA FOR END CORRECTION
@@ -261,14 +283,18 @@ C     IMAGINARY PART SMOOTHING
 C
       SUBROUTINE ECORSI(FS,LAGH1,FS1,LAGSHF,LA1)
 C     FS SHIFT-RIGHT BY LA FOR IMAGINARY PART END CORRECTION
-      IMPLICIT REAL*8(A-H,O-Z)
-      DIMENSION FS(LAGH1),FS1(LAGSHF)
+cxx      IMPLICIT REAL*8(A-H,O-Z)
+cxx      DIMENSION FS(LAGH1),FS1(LAGSHF)
+      INTEGER :: LAGH1, LAGSHF, LA1
+      REAL(8) :: FS(LAGH1), FS1(LAGSHF)
       LAGH2=LAGH1+1
       LA=LA1-1
       DO 100 I=1,LAGH1
       I1=LAGH2-I
       I2=I1+LA
-  100 FS1(I2)=FS(I1)
+cxx  100 FS1(I2)=FS(I1)
+      FS1(I2)=FS(I1)
+  100 CONTINUE
       LA2=LAGH1+LA
       DO 110 I=1,LA
       I1=LA1-I
@@ -276,7 +302,9 @@ C     FS SHIFT-RIGHT BY LA FOR IMAGINARY PART END CORRECTION
       I3=LA2-I
       I4=LA2+I
       FS1(I1)=-FS1(I2)
-  110 FS1(I4)=-FS1(I3)
+cxx  110 FS1(I4)=-FS1(I3)
+      FS1(I4)=-FS1(I3)
+  110 CONTINUE
       RETURN
       END SUBROUTINE
 C
@@ -285,8 +313,11 @@ C     FOURIER TRANSFORM (GOERTZEL METHOD)
 C     THIS SUBROUTINE COMPUTES FOURIER TRANSFORM OF G(I),I=0,1,...,LG AT
 C     FREQUENCIES K/(2*LF),K=0,1,...,LF AND RETURNS SIN TRANSFORM IN
 C     FS(K).
-      IMPLICIT REAL*8(A-H,O-Z)
-      DIMENSION G(LGP1),FS(LF1)
+cxx      IMPLICIT REAL*8(A-H,O-Z)
+cxx      DIMENSION G(LGP1),FS(LF1)
+      INTEGER :: LGP1 ,LF1
+      REAL(8) :: G(LGP1), FS(LF1)
+      REAL(8) :: T, PI, ALF, AK, TK, CK, SK, CK2, UM0, UM1, UM2
       LG=LGP1-1
       LF=LF1-1
 C     REVERSAL OF G(I),I=1,...,LGP1 INTO G(LG3-I)   LG3=LGP1+1
@@ -297,7 +328,9 @@ C     REVERSAL OF G(I),I=1,...,LGP1 INTO G(LG3-I)   LG3=LGP1+1
       I2=LG3-I
       T=G(I)
       G(I)=G(I2)
-  100 G(I2)=T
+cxx  100 G(I2)=T
+      G(I2)=T
+  100 CONTINUE
   110 PI=3.1415926536
       ALF=LF
       T=PI/ALF
@@ -313,7 +346,9 @@ C     REVERSAL OF G(I),I=1,...,LGP1 INTO G(LG3-I)   LG3=LGP1+1
       DO 11 I=1,LG
       UM0=CK2*UM1-UM2+G(I)
       UM2=UM1
-   11 UM1=UM0
+cxx   11 UM1=UM0
+      UM1=UM0
+   11 CONTINUE
    12 FS(K)=SK*UM1
    10 CONTINUE
       RETURN
@@ -321,9 +356,13 @@ C     REVERSAL OF G(I),I=1,...,LGP1 INTO G(LG3-I)   LG3=LGP1+1
 C
       SUBROUTINE SIMCOH(P1,P2,C,S,P3,LAGH1)
 C     THIS SUBROUTINE COMPUTES SIMPLE COHERENCE.
-      IMPLICIT REAL*8(A-H,O-Z)
-      DIMENSION P1(LAGH1),P2(LAGH1),C(LAGH1),S(LAGH1),P3(LAGH1)
+cxx      IMPLICIT REAL*8(A-H,O-Z)
+cxx      DIMENSION P1(LAGH1),P2(LAGH1),C(LAGH1),S(LAGH1),P3(LAGH1)
+      INTEGER :: LAGH1
+      REAL(8) :: P1(LAGH1), P2(LAGH1), C(LAGH1), S(LAGH1), P3(LAGH1)
       DO 10 I=1,LAGH1
-   10 P3(I)=(P1(I)**2+P2(I)**2)/(C(I)*S(I))
+cxx   10 P3(I)=(P1(I)**2+P2(I)**2)/(C(I)*S(I))
+      P3(I)=(P1(I)**2+P2(I)**2)/(C(I)*S(I))
+   10 CONTINUE
       RETURN
       END SUBROUTINE
