@@ -5,19 +5,23 @@ c
       INCLUDE 'timsac_f.h'
 cc      !DEC$ ATTRIBUTES DLLEXPORT::SPGRHF
 c
-      IMPLICIT REAL*8(A-H,O-Z)                                          
+cxx      IMPLICIT REAL*8(A-H,O-Z)                                          
 cc      INTEGER H,H1                                                      
-      INTEGER PERIOD
+cxx      INTEGER PERIOD
 CC      REAL*4 X,SXX,BMYA,BMYM                                            
 cc      DIMENSION Y(1)                                                    
 cc      DIMENSION X(4000),CXX(1001)                                       
 cc      DIMENSION A(101),B(101)                                           
 cc      DIMENSION SXX(501)                                                
-      DIMENSION Y(N)
-      DIMENSION CXX(LAGH1),CN(LAGH1)
-      DIMENSION A(IFPL1),B(IFPL1)
-      DIMENSION PXX(LAGH1)
-      DIMENSION SD(IFPL1),AIC(IFPL1),PARCOR(IFPL1-1)
+cxx      DIMENSION Y(N)
+cxx      DIMENSION CXX(LAGH1),CN(LAGH1)
+cxx      DIMENSION A(IFPL1),B(IFPL1)
+cxx      DIMENSION PXX(LAGH1)
+cxx      DIMENSION SD(IFPL1),AIC(IFPL1),PARCOR(IFPL1-1)
+      INTEGER :: N, LAGH1, IFPL1, MODE, PERIOD, IER
+      REAL(8) :: Y(N), CXX(LAGH1), CN(LAGH1), XMEAN, SD(IFPL1),
+     1           AIC(IFPL1), PARCOR(IFPL1-1), PXX(LAGH1)
+      REAL(8) :: A(IFPL1), B(IFPL1), SGME2, OAIC
 C
 cc      H=60                                                              
 cc      H1=H+1                                                            
@@ -43,11 +47,12 @@ cc      CALL SICP2(CXX,IFPL1,N,A,L,SGME2,OAIC)
 cc      WRITE(6,50)                                                       
       K=0                                                               
 cc 1031 CALL SNRASP(A,B,SXX,SGME2,L,K,H1,BMYA,BMYM)                       
- 1031 CALL SNRASP(A,B,PXX,SGME2,L,K,LAGH1,PERIOD)
+cxx 1031 CALL SNRASP(A,B,PXX,SGME2,L,K,LAGH1,PERIOD)
+      CALL SNRASP(A,B,PXX,SGME2,L,K,LAGH1,PERIOD)
 C
       RETURN                                                            
-   50 FORMAT(1H ,'*** HIGH ORDER AR-SPECTRUM AS AN APPROXIMATION TO PERI
-     *ODGRAM (ORDER IS FIXED AT 30 ) ***')                              
+cxx   50 FORMAT(1H ,'*** HIGH ORDER AR-SPECTRUM AS AN APPROXIMATION TO PERI
+cxx     *ODGRAM (ORDER IS FIXED AT 30 ) ***')                              
       END                                                               
 cc      SUBROUTINE SICP2(CYY,L1,N,COEF,MO,OSD,OAIC)                       
       SUBROUTINE SICP2(CYY,L1,N,COEF,MO,OSD,OAIC,SD1,AIC1,PARCOR,IER)
@@ -63,11 +68,16 @@ C     COEF; AR-COEFFICIENTS
 C     MO: ORDER OF AR                                                   
 C     OSD: INNOVATION VARIANCE                                          
 C     OAIC: VALUE OF AIC                                                
-      IMPLICIT REAL*8(A-H,O-Z)                                          
-      DIMENSION CYY(L1),COEF(L1)                                        
+cxx      IMPLICIT REAL*8(A-H,O-Z)                                          
+cxx      DIMENSION CYY(L1),COEF(L1)                                        
 cc      DIMENSION A(101),B(101)                                           
-      DIMENSION A(L1),B(L1)
-      DIMENSION SD1(L1),AIC1(L1),PARCOR(L1-1)
+cxx      DIMENSION A(L1),B(L1)
+cxx      DIMENSION SD1(L1),AIC1(L1),PARCOR(L1-1)
+      INTEGER :: L1, N, MO, IER
+      REAL(8) :: CYY(L1), COEF(L1), OSD, OAIC, SD1(L1), AIC1(L1),
+     1           PARCOR(L1-1)
+      REAL(8) :: A(L1), B(L1), CST0, CST1, CST2, CST20, CST05, CST01,
+     1           SD, AN, RAN, SCALH, AIC, SE, SDR, D, D2, AM, ANFC
 cc      REAL*4 AX,BL,STA,DASH,PLUS                                        
 cc      REAL*4 FFFF                                                       
 cc      REAL*4  F(41) / 41*1H  /, AMES(41) / 41*1H- /                     
@@ -92,14 +102,17 @@ cc  991 CONTINUE
 C     WRITE(6,1100)                                                     
       RAN=CST1/DSQRT(AN)                                                
       SCALH=CST20                                                       
-      JJ0=SCALH+CST1                                                    
-      JJL=SCALH*CST2+CST1                                               
+cxx      JJ0=SCALH+CST1                                                    
+cxx      JJL=SCALH*CST2+CST1                                               
+      JJ0=INT(SCALH+CST1)
+      JJL=INT(SCALH*CST2+CST1)
 cc      AMES(1)=PLUS                                                      
 cc      AMES(11)=PLUS                                                     
 cc      AMES(JJ0)=PLUS                                                    
 cc      AMES(JJ0+10)=PLUS                                                 
 cc      AMES(JJL)=PLUS                                                    
-      IAN=SCALH*(RAN+CST05)                                             
+cxx      IAN=SCALH*(RAN+CST05)                                             
+      IAN=INT(SCALH*(RAN+CST05))
       IAN1=IAN+JJ0                                                      
       IAN2=2*IAN+JJ0                                                    
       LAN1=-IAN+JJ0                                                     
@@ -148,14 +161,19 @@ C     A(I) COMPUTATION
   410 CONTINUE                                                          
       DO 421 I=1,M                                                      
       IM=MP1-I                                                          
-  421 B(I)=A(IM)                                                        
+cxx  421 B(I)=A(IM)
+      B(I)=A(IM)
+  421 CONTINUE
 C     M,SD,AIC  PRINT OUT                                               
       IF(A(M).LT.CST0) GO TO 300                                        
-      NFC=SCALH*(A(M)+CST05)                                            
+cxx      NFC=SCALH*(A(M)+CST05)                                            
+      NFC=INT(SCALH*(A(M)+CST05))
       GO TO 310                                                         
-  300 NFC=SCALH*(A(M)-CST05)                                            
+cxx  300 NFC=SCALH*(A(M)-CST05)                                            
+  300 NFC=INT(SCALH*(A(M)-CST05))
   310 ANFC=NFC                                                          
-      JJ=ANFC+SCALH+CST1                                                
+cxx      JJ=ANFC+SCALH+CST1                                                
+      JJ=INT(ANFC+SCALH+CST1)                                                
 cc      FFFF=F(JJ)                                                        
 cc      F(JJ)=STA                                                         
 cc      WRITE(6,860) M,SD,AIC,A(M),(F(J),J=1,JJL)                         
@@ -164,7 +182,8 @@ cc      WRITE(6,860) M,SD,AIC,A(M),(F(J),J=1,JJL)
       PARCOR(M)=A(M)
 cc      F(JJ)=FFFF                                                        
 C                                                                       
-  990 IF(OAIC.LT.AIC) GO TO 440                                         
+cxx  990 IF(OAIC.LT.AIC) GO TO 440                                         
+      IF(OAIC.LT.AIC) GO TO 440
       OAIC=AIC                                                          
       OSD=SD                                                            
       MO=M                                                              
@@ -174,7 +193,9 @@ C 430 COEF(I)=-A(I)
   440 IF(M.EQ.L) GO TO 400                                              
       SE=CYY(M+2)                                                       
       DO 441 I=1,M                                                      
-  441 SE=SE-B(I)*CYY(I+1)                                               
+cxx  441 SE=SE-B(I)*CYY(I+1)                                               
+      SE=SE-B(I)*CYY(I+1)
+  441 CONTINUE
   400 CONTINUE
   402 CONTINUE
 cc      WRITE(6,870) OAIC,MO                                              
@@ -182,7 +203,9 @@ cc      WRITE(6,870) OAIC,MO
       OSD=SD                                                            
       MO=L                                                              
       DO 5100 I=1,L                                                     
- 5100 COEF(I)=-A(I)                                                     
+cxx 5100 COEF(I)=-A(I)
+      COEF(I)=-A(I)
+ 5100 CONTINUE
 C                                                                       
 C     MO, COEF(I) OUT PUT                                               
 C     WRITE(6,1871)                                                     
@@ -197,25 +220,25 @@ cc      AMES(JJ0)=DASH
 cc      AMES(JJ0+10)=DASH                                                 
 cc      AMES(JJL)=DASH                                                    
       RETURN                                                            
-26100 FORMAT(1H ,16X,'SD(M)',15X,'AIC(M)',13X,'A(M)')                   
-26101 FORMAT(1H ,////,4X,'M',11X,'INNOVATION',10X,'AIC(M)=    ',8X,     
-     A      'PARTIAL AUTO-')                                            
-  261 FORMAT(1H ,16X,'   VARIANCE',9X,'N*DLOG(SD(M))+2*M',              
-     A      '  CORRELATION    ',                                        
-     A      'PARTIAL CORRELATION (LINES SHOW +SD AND +2SD)')            
-26102 FORMAT(1H+,102X,'_',7X,'_')                                       
-  262 FORMAT(1H ,69X,'-1',19X,'0',19X,'1')                              
-  264 FORMAT(1H ,70X,41A1)                                              
-  859 FORMAT(1H ,I5,2X,2D20.5)                                          
-  860 FORMAT(1H ,I5,2X,3D20.5,3X,41A1)                                  
-  861 FORMAT(1H+,70X,41A1)                                              
-  960 FORMAT(1H ,5X,'A(I)')                                             
-  870 FORMAT(/,1H ,'MINIMUM AIC(M)=',D12.5,2X,'ATTAINED AT M=',I5/)     
-  980 FORMAT(1H ,5X,'COEF(I)')                                          
- 1100 FORMAT(1H ,'AIC(M)=N*DLOG(SD)+2*M')                               
-  871 FORMAT(1H ,'AR-COEFFICIENTS')                                     
- 1871 FORMAT(1H ,'AR MODEL: Y(N)+AR(1)Y(N-1)+...+AR(M)Y(N-M)=X(N)')     
- 2600 FORMAT(1H ,'ACCURACY OF COMPUTATION LOST')                        
+cxx26100 FORMAT(1H ,16X,'SD(M)',15X,'AIC(M)',13X,'A(M)')                   
+cxx26101 FORMAT(1H ,////,4X,'M',11X,'INNOVATION',10X,'AIC(M)=    ',8X,     
+cxx     A      'PARTIAL AUTO-')                                            
+cxx  261 FORMAT(1H ,16X,'   VARIANCE',9X,'N*DLOG(SD(M))+2*M',              
+cxx     A      '  CORRELATION    ',                                        
+cxx     A      'PARTIAL CORRELATION (LINES SHOW +SD AND +2SD)')
+cxx26102 FORMAT(1H+,102X,'_',7X,'_')                                       
+cxx  262 FORMAT(1H ,69X,'-1',19X,'0',19X,'1')                              
+cxx  264 FORMAT(1H ,70X,41A1)                                              
+cxx  859 FORMAT(1H ,I5,2X,2D20.5)                                          
+cxx  860 FORMAT(1H ,I5,2X,3D20.5,3X,41A1)                                  
+cxx  861 FORMAT(1H+,70X,41A1)                                              
+cxx  960 FORMAT(1H ,5X,'A(I)')                                             
+cxx  870 FORMAT(/,1H ,'MINIMUM AIC(M)=',D12.5,2X,'ATTAINED AT M=',I5/)     
+cxx  980 FORMAT(1H ,5X,'COEF(I)')                                          
+cxx 1100 FORMAT(1H ,'AIC(M)=N*DLOG(SD)+2*M')                               
+cxx  871 FORMAT(1H ,'AR-COEFFICIENTS')                                     
+cxx 1871 FORMAT(1H ,'AR MODEL: Y(N)+AR(1)Y(N-1)+...+AR(M)Y(N-M)=X(N)')     
+cxx 2600 FORMAT(1H ,'ACCURACY OF COMPUTATION LOST')                        
       END                                                               
 cc      SUBROUTINE SNRASP(A,B,SXX,SGME2,L,K,H1,BMYA,BMYM)                 
       SUBROUTINE SNRASP(A,B,PXX,SGME2,L,K,H1,IPPP)
@@ -227,9 +250,9 @@ C     I=0,1,...,H.
 C     REQUIRED INPUTS ARE:                                              
 C     L,K,H,SGME2,(A(I),I=1,L), AND (B(I),I=1,K).                       
 C     0 IS ALLOWABLE AS L AND/OR K.                                     
-      IMPLICIT REAL*8(A-H,O-Z)                                          
+cxx      IMPLICIT REAL*8(A-H,O-Z)                                          
 cc      INTEGER H,H1                                                      
-      INTEGER H1                                                      
+cxx      INTEGER H1                                                      
 CC      REAL*4 SXX,BMYA,BMYM,FY
 cc      REAL*4 FY                                           
 cc      INTEGER F,AX,BL,STA                                               
@@ -237,38 +260,50 @@ cc      DIMENSION F(61),FY(10)
 cc      DIMENSION A(101),B(101)                                           
 cc      DIMENSION G(501),GR1(501),GI1(501),GR2(501),GI2(501)              
 cc      DIMENSION PXX(501),SXX(501)                                       
-      DIMENSION A(L),B(K)                                           
-      DIMENSION G(L+K+1),GR1(H1),GI1(H1),GR2(H1),GI2(H1)
-      DIMENSION PXX(H1)
+cxx      DIMENSION A(L),B(K)                                           
+cxx      DIMENSION G(L+K+1),GR1(H1),GI1(H1),GR2(H1),GI2(H1)
+cxx      DIMENSION PXX(H1)
+      INTEGER :: L, K, H1, IPPP
+      REAL(8) :: A(L), B(K), PXX(H1), SGME2
+      REAL(8) :: G(L+K+1), GR1(H1), GI1(H1), GR2(H1), GI2(H1),
+     1           CST0, CST1, T0
 cc      COMMON /ILOGT/IDUMMY(2),IPUNC                                     
 cc      COMMON /IDATA/IPPP                                                
 cc      DATA AX/1H!/                                                      
 cc      DATA BL,STA/1H ,1H*/                                              
       IPPP0=120/IPPP                                                    
       CST0=0.0D-00                                                      
-      CST1=1.0D-00                                                      
-  310 CONTINUE                                                          
+      CST1=1.0D-00
+cxx  310 CONTINUE                                                          
       IF(L.LE.0) GO TO 320                                              
       DO 330 I=1,L                                                      
-  330 A(I)=-A(I)                                                        
+cxx  330 A(I)=-A(I)                                                        
+      A(I)=-A(I)
+  330 CONTINUE
   320 L1=L+1                                                            
       K1=K+1                                                            
       G(1)=CST1                                                         
       IF(L.LE.0) GO TO 400                                              
       DO 10 I=1,L                                                       
       I1=I+1                                                            
-   10 G(I1)=-A(I)                                                       
+cxx   10 G(I1)=-A(I)
+      G(I1)=-A(I)
+   10 CONTINUE
 C     COMMON SUBROUTINE CALL                                            
   400 CALL FOUGER(G,L1,GR1,GI1,H1)                                      
       G(1)=CST1                                                         
       IF(K.LE.0) GO TO 410                                              
       DO 20 I=1,K                                                       
       I1=I+1                                                            
-   20 G(I1)=B(I)                                                        
+cxx   20 G(I1)=B(I)                                                        
+      G(I1)=B(I)
+   20 CONTINUE
 C     COMMON SUBROUTINE CALL                                            
   410 CALL FOUGER(G,K1,GR2,GI2,H1)                                      
       DO 30 I=1,H1                                                      
-   30 PXX(I)=(GR2(I)**2+GI2(I)**2)/(GR1(I)**2+GI1(I)**2)*SGME2          
+cxx   30 PXX(I)=(GR2(I)**2+GI2(I)**2)/(GR1(I)**2+GI1(I)**2)*SGME2
+      PXX(I)=(GR2(I)**2+GI2(I)**2)/(GR1(I)**2+GI1(I)**2)*SGME2
+   30 CONTINUE
 C     WRITE(6,60)                                                       
 C     WRITE(6,160)                                                      
 C     WRITE(6,61) L,K,H                                                 
@@ -277,7 +312,9 @@ C     WRITE(6,264)
 C     WRITE(6,265)                                                      
       IF(L.LE.0) GO TO 500                                              
       DO 340 I=1,L                                                      
-  340 A(I)=-A(I)                                                        
+cxx  340 A(I)=-A(I)
+      A(I)=-A(I)
+  340 CONTINUE
 C     WRITE(6,62)                                                       
 C     COMMON SUBROUTINE CALL                                            
 C     CALL SUBVCP(A,L)                                                  
@@ -338,13 +375,13 @@ cc  700 FORMAT(I5)
 cc  701 FORMAT('(6D12.5)')                                                
 cc  702 FORMAT(6D12.5)                                                    
       RETURN                                                            
-   60 FORMAT(//1H ,'RATIONAL SPECTRUM')                                 
-   61 FORMAT(1H ,2HL=,I5,2X,2HK=,I5,2X,2HH=,I5)                         
-   62 FORMAT(1H ,5X,'AR(I)')                                            
-   63 FORMAT(1H ,5X,'MA(I)')                                            
-  160 FORMAT(1H ,17HINITIAL CONDITION)                                  
-  164 FORMAT(1H ,6HSGME2=,D12.5)                                        
-  264 FORMAT(1H ,'AR-MA MODEL:')                                        
-  265 FORMAT(1H ,'Y(N)+AR(1)Y(N-1)+...+AR(L)Y(N-L)=X(N)+MA(1)X(N-1)+...+
-     AMA(K)X(N-K)')                                                     
+cxx   60 FORMAT(//1H ,'RATIONAL SPECTRUM')                                 
+cxx   61 FORMAT(1H ,2HL=,I5,2X,2HK=,I5,2X,2HH=,I5)                         
+cxx   62 FORMAT(1H ,5X,'AR(I)')                                            
+cxx   63 FORMAT(1H ,5X,'MA(I)')                                            
+cxx  160 FORMAT(1H ,17HINITIAL CONDITION)                                  
+cxx  164 FORMAT(1H ,6HSGME2=,D12.5)                                        
+cxx  264 FORMAT(1H ,'AR-MA MODEL:')                                        
+cxx  265 FORMAT(1H ,'Y(N)+AR(1)Y(N-1)+...+AR(L)Y(N-L)=X(N)+MA(1)X(N-1)+...+
+cxx     AMA(K)X(N-K)')                                                     
       END                                                               
